@@ -3,9 +3,12 @@ from dataclasses import dataclass
 from pollination.honeybee_radiance.translate import CreateRadianceFolderGrid
 from pollination.honeybee_radiance.sky import CreateSkyDome, CreateSkyMatrix
 from pollination.honeybee_radiance.sun import CreateSunMatrix, ParseSunUpHours
-from pollination.honeybee_radiance.multiphase import CreateOctreesGrids
+from pollination.honeybee_radiance.multiphase import PrepareDynamic
+
+from pollination.path.read import ReadJSONList
 
 from .two_phase.entry import TwoPhaseEntryPoint
+from .two_phase.dynamic.entry import DynamicGroup
 from .three_phase.preparation import ThreePhaseInputsPreparation
 from .three_phase.calculation import ThreePhaseMatrixCalculation
 
@@ -40,17 +43,17 @@ class RecipeEntryPoint(DAG):
 
     radiance_parameters = Inputs.str(
         description='The radiance parameters for ray tracing.',
-        default='-ab 1 -ad 100 -lw 0.01'
+        default='-ab 3 -ad 5000 -lw 1e-4'
     )
 
     view_mtx_rad_params = Inputs.str(
         description='The radiance parameters for ray tracing.',
-        default='-ab 2 -ad 5000 -lw 2e-05'
+        default='-ab 3 -ad 1000 -lw 5e-4'
     )
 
     daylight_mtx_rad_params = Inputs.str(
         description='The radiance parameters for ray tracing.',
-        default='-ab 2 -ad 5000 -lw 2e-05'
+        default='-ab 3 -ad 1000 -lw 5e-4 -c 500'
     )
 
     grid_filter = Inputs.str(
@@ -164,43 +167,43 @@ class RecipeEntryPoint(DAG):
             }
         ]
 
-    @task(template=CreateOctreesGrids, needs=[create_rad_folder, generate_sunpath])
-    def create_octrees_grids(
+    @task(template=PrepareDynamic, needs=[create_rad_folder, generate_sunpath])
+    def prepare_dynamic(
         self, model=create_rad_folder._outputs.model_folder,
-        sunpath=generate_sunpath._outputs.sunpath, phase='3', cpu_count=cpu_count,
-        cpus_per_grid=3, min_sensor_count=min_sensor_count
+        sunpath=generate_sunpath._outputs.sunpath, phase=3, cpu_count=cpu_count,
+        cpus_per_grid=3, min_sensor_count=min_sensor_count, static='include'
     ):
         return [
             {
-                'from': CreateOctreesGrids()._outputs.scene_folder,
+                'from': PrepareDynamic()._outputs.scene_folder,
                 'to': 'resources/octrees'
             },
             {
-                'from': CreateOctreesGrids()._outputs.grid_folder,
+                'from': PrepareDynamic()._outputs.grid_folder,
                 'to': 'resources/grid'
             },
             {
-                'from': CreateOctreesGrids()._outputs.scene_info
+                'from': PrepareDynamic()._outputs.scene_info
             },
             {
-                'from': CreateOctreesGrids()._outputs.two_phase_info
+                'from': PrepareDynamic()._outputs.two_phase_info
             }
         ]
 
     @task(
-        template=TwoPhaseEntryPoint,
-        loop=create_octrees_grids._outputs.two_phase_info,
+        template=DynamicGroup,
+        loop=prepare_dynamic._outputs.two_phase_info,
         needs=[
-            create_rad_folder, create_octrees_grids,
+            create_rad_folder, prepare_dynamic,
             create_total_sky, create_direct_sky, create_sky_dome,
             generate_sunpath
         ],
         sub_folder='calcs/2_phase/{{item.identifier}}',
         sub_paths={
-            'octree': '{{item.octree}}',
-            'octree_direct': '{{item.octree_direct}}',
-            'octree_direct_sun': '{{item.octree_direct_sun}}',
-            'sensor_grids_folder': '{{item.light_path}}'
+            'octree_file': '{{item.octree}}',
+            'octree_file_direct': '{{item.octree_direct}}',
+            'octree_file_with_suns': '{{item.octree_direct_sun}}',
+            'sensor_grids_folder': '{{item.sensor_grids_folder}}'
         }
     )
     def calculate_two_phase_matrix(
@@ -208,10 +211,10 @@ class RecipeEntryPoint(DAG):
         identifier='{{item.identifier}}',
         radiance_parameters=radiance_parameters,
         sensor_grids_info='{{item.sensor_grids_info}}',
-        sensor_grids_folder=create_octrees_grids._outputs.grid_folder,
-        octree=create_octrees_grids._outputs.scene_folder,
-        octree_direct=create_octrees_grids._outputs.scene_folder,
-        octree_direct_sun=create_octrees_grids._outputs.scene_folder,
+        sensor_grids_folder=prepare_dynamic._outputs.grid_folder,
+        octree_file=prepare_dynamic._outputs.scene_folder,
+        octree_file_direct=prepare_dynamic._outputs.scene_folder,
+        octree_file_with_suns=prepare_dynamic._outputs.scene_folder,
         sky_dome=create_sky_dome._outputs.sky_dome,
         total_sky=create_total_sky._outputs.sky_matrix,
         direct_sky=create_direct_sky._outputs.sky_matrix,
@@ -224,7 +227,7 @@ class RecipeEntryPoint(DAG):
     @task(
         template=ThreePhaseInputsPreparation,
         needs=[
-            create_rad_folder, create_octrees_grids,
+            create_rad_folder, prepare_dynamic,
             create_total_sky, create_sky_dome
         ],
         sub_folder='calcs/3_phase/',
@@ -235,17 +238,19 @@ class RecipeEntryPoint(DAG):
     def prepare_three_phase(
         self,
         model_folder=create_rad_folder._outputs.model_folder,
-        octree=create_octrees_grids._outputs.scene_folder,
+        octree=prepare_dynamic._outputs.scene_folder,
         sky_dome=create_sky_dome._outputs.sky_dome,
         bsdf_folder=create_rad_folder._outputs.bsdf_folder,
         dmtx_group_params=dmtx_group_params
     ):
         return [
             {
-                'from': ThreePhaseInputsPreparation()._outputs.multiplication_info
+                'from': ThreePhaseInputsPreparation()._outputs.multiplication_info,
+                'to': '../../calcs/3_phase/info/multiplication_info.json'
             },
             {
-                'from': ThreePhaseInputsPreparation()._outputs.grouped_apertures_info
+                'from': ThreePhaseInputsPreparation()._outputs.grouped_apertures_info,
+                'to': '../../calcs/3_phase/info/grouped_apertures_info.json'
             },
             {
                 'from': ThreePhaseInputsPreparation()._outputs.grouped_apertures_folder,
@@ -257,12 +262,18 @@ class RecipeEntryPoint(DAG):
             }
         ]
 
+    @task(template=ReadJSONList, needs=[prepare_three_phase])
+    def multiplication_info_to_json(
+            self, src=prepare_three_phase._outputs.multiplication_info
+            ):
+        return [{'from': ReadJSONList()._outputs.data}]
+
     @task(
         template=ThreePhaseMatrixCalculation,
         needs=[
-            create_rad_folder, create_octrees_grids,
+            create_rad_folder, prepare_dynamic,
             create_total_sky, create_sky_dome,
-            prepare_three_phase
+            prepare_three_phase, multiplication_info_to_json
         ],
         sub_folder='calcs/3_phase',
         sub_paths={
@@ -272,13 +283,12 @@ class RecipeEntryPoint(DAG):
     def calculate_three_phase_matrix_total(
         self,
         model_folder=create_rad_folder._outputs.model_folder,
-        grouped_apertures=prepare_three_phase._outputs.grouped_apertures_info,
         grouped_apertures_folder=prepare_three_phase._outputs.grouped_apertures_folder,
-        multiplication_info=prepare_three_phase._outputs.multiplication_info,
+        multiplication_info=multiplication_info_to_json._outputs.data,
         receivers=create_rad_folder._outputs.receivers,
         view_mtx_rad_params=view_mtx_rad_params,
         daylight_mtx_rad_params=daylight_mtx_rad_params,
-        octree=create_octrees_grids._outputs.scene_folder,
+        octree=prepare_dynamic._outputs.scene_folder,
         sky_dome=create_sky_dome._outputs.sky_dome,
         sky_matrix=create_total_sky._outputs.sky_matrix,
         bsdf_folder=create_rad_folder._outputs.bsdf_folder,
